My Test Program
---------------

This is a simple test program that I made to learn how to package python
code for PyPI.  I plan to roughly follow the tutorial at
http://python-packaging.readthedocs.org/en/latest/metadata.html and play with
nose and tox for testing, and sphinx for documentation.
